"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.calculatePoolUnits = void 0;
const bignumber_js_1 = __importDefault(require("bignumber.js"));
const common_1 = require("./common");
function calculatePoolUnits(nativeAmount, externalAmount, pooledNativeAmount, pooledExternalAmount, poolUnits) {
    const na = new bignumber_js_1.default(nativeAmount);
    const ea = new bignumber_js_1.default(externalAmount);
    const pna = new bignumber_js_1.default(pooledNativeAmount);
    const pea = new bignumber_js_1.default(pooledExternalAmount);
    const pu = new bignumber_js_1.default(poolUnits);
    if (pea.isZero() || pna.isZero() || pu.isZero()) {
        return new bignumber_js_1.default(nativeAmount);
    }
    if (ea.isZero() && na.isZero()) {
        return new bignumber_js_1.default(0);
    }
    const slipAdjustmentCalc = (0, common_1.calculateSlipAdjustment)(nativeAmount, externalAmount, pooledNativeAmount, pooledExternalAmount);
    // ((P (a R + A r))
    const numerator = pu.times(ea.times(pooledNativeAmount).plus(new bignumber_js_1.default(pooledExternalAmount).times(nativeAmount)));
    const denominator = new bignumber_js_1.default(2).times(pooledExternalAmount).times(pooledNativeAmount);
    return numerator.div(denominator).times(slipAdjustmentCalc);
}
exports.calculatePoolUnits = calculatePoolUnits;
