"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.calculateSlipAdjustment = void 0;
const bignumber_js_1 = __importDefault(require("bignumber.js"));
/**
 * calculate slip adjustment based on formula 1 - ABS((R a - r A)/((2 r + R) (a + A)))
 * @param leftAmount
 * @param rightAmount
 * @param leftPoolAmount
 * @param rightPoolAmount
 * @returns slip adjustment
 */
const calculateSlipAdjustment = (leftAmount, rightAmount, leftPoolAmount, rightPoolAmount) => {
    const l = new bignumber_js_1.default(leftAmount);
    const r = new bignumber_js_1.default(rightAmount);
    const lp = new bignumber_js_1.default(leftPoolAmount);
    const rp = new bignumber_js_1.default(rightPoolAmount);
    const slipAdjDenominator = l.plus(lp).times(r.plus(rp));
    const slipAdjustmentReciprocal = lp.times(r).gt(l.times(rp))
        ? lp.times(r).minus(l.times(rp)).div(slipAdjDenominator)
        : l.times(rp).minus(lp.times(r)).div(slipAdjDenominator);
    return new bignumber_js_1.default(1).minus(slipAdjustmentReciprocal);
};
exports.calculateSlipAdjustment = calculateSlipAdjustment;
