import BigNumber from "bignumber.js";
/**
 * calculate Swap Result based on formula (( x * X * Y ) / ( x + X ) ^ 2) * (1 + adjustment / 100)
 * @param fromAmount
 * @param fromCoinPoolAmount
 * @param toCoinPoolAmount
 * @param adjustment PMTP purchasing power adjustment, `undefined` if no adjustment is needed
 * @returns amount obtained from swap
 */
export declare const calculateSwapResult: (fromAmount: BigNumber.Value, fromCoinPoolAmount: BigNumber.Value, toCoinPoolAmount: BigNumber.Value, adjustment?: BigNumber.Value) => BigNumber;
/**
 * formula: S = (x * X * Y) / (x + X) ^ 2
 * reverse Formula: x = ( -2*X*S + X*Y - X*sqrt( Y*(Y - 4*S) ) ) / 2*S
 * ok to accept a little precision loss as reverse swap amount can be rough
 * @param targetAmount
 * @param targetCoinPoolAmount
 * @param fromCoinPoolAmount
 * @returns
 */
export declare const calculateSwapAmountNeeded: (targetAmount: BigNumber.Value, targetCoinPoolAmount: BigNumber.Value, fromCoinPoolAmount: BigNumber.Value) => BigNumber;
/**
 * calculate Provider Fee according to the formula: ( x^2 * Y ) / ( x + X )^2
 * @param fromAmount swap Amount
 * @param fromCoinPoolAmount external Balance
 * @param toCoinPoolAmount native Balance
 * @returns providerFee
 */
export declare const calculateLiquidityProviderFee: (fromAmount: BigNumber.Value, fromCoinPoolAmount: BigNumber.Value, toCoinPoolAmount: BigNumber.Value) => BigNumber;
/**
 * calculate price impact according to the formula (x) / (x + X)
 * @param fromAmount swap Amount
 * @param fromCoinPoolAmount external Balance
 * @returns
 */
export declare const calculatePriceImpact: (fromAmount: BigNumber.Value, fromCoinPoolAmount: BigNumber.Value) => BigNumber;
